@@ -262,6 +262,10 @@ def on_review_request_publishing(user, review_request_draft, **kwargs):
         users = get_or_create_bugzilla_users(user_data)
         reviewers.append(users[0].email)
 
+    # Sorted so behavior is deterministic (this mucks with test output
+    # otherwise).
+    reviewers = sorted(reviewers)
+
     # Don't make attachments for child review requests, otherwise,
     # Bugzilla gets inundatated with lots of patches, and the squashed
     # one is the only one we want to post there.
@@ -346,7 +350,7 @@ def on_review_publishing(user, review, **kwargs):
     b = Bugzilla(user.bzlogin, user.bzcookie)
 
     if review.ship_it and is_review_request_squashed(review_request):
-        b.r_plus_attachment(bug_id, review.user.username, comment,
+        b.r_plus_attachment(bug_id, review.user.email, comment,
                             review_or_request_url(review_request, site,
                                                   siteconfig))
     else:
